@@ -214,7 +214,7 @@ class StaticFiles(object):
 
     def install(self, destdir, **kwargs):
         installer = StaticInstaller(self, **kwargs)
-        installer.install_tree(self.root, os.path.abspath(destdir))
+        installer.install_tree(self.root, ".", os.path.abspath(destdir))
 
 #
 # Installer Actual
@@ -267,17 +267,17 @@ class StaticInstaller(object):
                     stream = rule(ctx, stream)
         return stream
 
-    def install_tree(self, frompath, topath, root=True):
-        if root and self.clean:
+    def install_tree(self, root, frompath, topath, at_root=True):
+        if at_root and self.clean:
             shutil.rmtree(topath)
         mkdir_p(topath)
 
-        for name in os.listdir(frompath):
+        for name in os.listdir(os.path.join(root, frompath)):
             frompath_ = os.path.join(frompath, name)
             topath_ = os.path.join(topath, name)
-            if os.path.isdir(frompath_):
+            if os.path.isdir(os.path.join(root, frompath_)):
                 mkdir_p(topath_)
-                self.install_tree(frompath_, topath_, root = False)
+                self.install_tree(root, frompath_, topath_, at_root=False)
             else:
                 if self.verbose:
                     print(topath_)
